@@ -6,7 +6,6 @@ import java.math.BigInteger;
 import java.util.regex.Pattern;
 
 import org.yaml.snakeyaml.error.Mark;
-import org.yaml.snakeyaml.error.YAMLException;
 import org.yaml.snakeyaml.events.*;
 import org.yaml.snakeyaml.nodes.NodeId;
 import org.yaml.snakeyaml.nodes.Tag;
@@ -18,7 +17,6 @@ import com.fasterxml.jackson.core.base.ParserBase;
 import com.fasterxml.jackson.core.io.IOContext;
 import com.fasterxml.jackson.core.util.BufferRecycler;
 import com.fasterxml.jackson.core.util.ByteArrayBuilder;
-import com.fasterxml.jackson.databind.JsonMappingException;
 
 import org.yaml.snakeyaml.resolver.Resolver;
 
@@ -209,16 +207,6 @@ public class YAMLParser extends ParserBase
     /**********************************************************                              
      */
 
-    @Override
-    protected boolean loadMore() throws IOException {
-        throw new UnsupportedOperationException();
-    }
-
-    @Override
-    protected void _finishString() throws IOException {
-        throw new UnsupportedOperationException();
-    }
-
     @Override
     protected void _closeInput() throws IOException {
         _reader.close();
@@ -335,6 +323,7 @@ public class YAMLParser extends ParserBase
     /**********************************************************
      */
     
+    @SuppressWarnings("deprecation")
     @Override
     public JsonToken nextToken() throws IOException
     {
@@ -344,22 +333,17 @@ public class YAMLParser extends ParserBase
         if (_closed) {
             return null;
         }
-        
+
         while (true) {
             Event evt;
             try {
                 evt = _yamlParser.getEvent();
-            } catch (YAMLException e) {
-                /* 12-Mar-2016, tatu: It may look weird that we do NOT add cause
-                 *    as is, but see issue [dataformat-yaml#31] for details: basically,
-                 *    exposing a SnakeYAML type is leakage that can have nasty side effects
-                 */
-                String msg = String.format("YAML decoding problem: %s", e.getMessage());
-                // !!! TODO: In 2.8. use the new constructor from databind 2.7
-                JsonMappingException e2 = new JsonMappingException(msg);
-                // try to retain stack trace, however, for troubleshooting
-                e2.setStackTrace(e.getStackTrace());
-                throw e2;
+            } catch (org.yaml.snakeyaml.error.YAMLException e) {
+                if (e instanceof org.yaml.snakeyaml.error.MarkedYAMLException) {
+                    throw com.fasterxml.jackson.dataformat.yaml.snakeyaml.error.MarkedYAMLException.from
+                        (this, (org.yaml.snakeyaml.error.MarkedYAMLException) e);
+                }
+                throw com.fasterxml.jackson.dataformat.yaml.snakeyaml.error.YAMLException.from(this, e);
             }
             // is null ok? Assume it is, for now, consider to be same as end-of-doc
             if (evt == null) {
@@ -462,14 +446,18 @@ public class YAMLParser extends ParserBase
 
         if (typeTag == null || typeTag.equals("!")) { // no, implicit
             Tag nodeTag = _yamlResolver.resolve(NodeId.scalar, value, scalar.getImplicit().canOmitTagInPlainScalar());
+
             if (nodeTag == Tag.STR) {
-                return (_currToken = JsonToken.VALUE_STRING);
-            } else if (nodeTag == Tag.INT) {
+                return JsonToken.VALUE_STRING;
+            }
+            if (nodeTag == Tag.INT) {
                 return _decodeNumberScalar(value, len);
-            } else if (nodeTag == Tag.FLOAT) {
+            }
+            if (nodeTag == Tag.FLOAT) {
                 _numTypesValid = 0;
                 return JsonToken.VALUE_NUMBER_FLOAT;
-            } else if (nodeTag == Tag.BOOL) {
+            }
+            if (nodeTag == Tag.BOOL) {
                 Boolean B = _matchYAMLBoolean(value, len);
                 if (B != null) {
                     return B ? JsonToken.VALUE_TRUE : JsonToken.VALUE_FALSE;
@@ -571,7 +559,10 @@ public class YAMLParser extends ParserBase
             _numTypesValid = 0;
             return JsonToken.VALUE_NUMBER_FLOAT;
         }
-        return null;
+        
+        // 25-Aug-2016, tatu: If we can't actually match it to valid number,
+        //    consider String; better than claiming there's not toekn
+        return JsonToken.VALUE_STRING;
     }   
 
     /*
@@ -630,6 +621,17 @@ public class YAMLParser extends ParserBase
         return 0;
     }
 
+    @Override // since 2.8
+    public int getText(Writer writer) throws IOException
+    {
+        String str = getText();
+        if (str == null) {
+            return 0;
+        }
+        writer.write(str);
+        return str.length();
+    }
+
     /*
     /**********************************************************************
     /* Binary (base64)
